#ifndef KSYSGUARD_VERSION
#define KSYSGUARD_VERSION "4"
#endif
